Welcome to the ARA documentation!
=================================

Table of Contents
=================

.. toctree::
    :maxdepth: 2

    Frequently asked questions <faq>
    Installation <installation>
    Configuration <configuration>
    Usage <usage>
    Contributing <contributing>